==> rad_textures-1.0.6.tar.gz: web/RayTracedSphere.dart <==
import 'dart:html';
import 'package:rad_textures/rad_textures.dart';
import 'package:vector_math/vector_math.dart';

void main() {
  window.onLoad.listen((e) => _create());
}

num /*shade*/ SphereRay(Vector3 vCamera, Vector3 vSphere, Vector3 vScreen) {
  Vector3 vCast = vScreen - vCamera;
  double scale = intersectRaySphere(vCamera, vCast, vSphere, 5.0);
  if(double.INFINITY != scale) {
    Vector3 intersect = vCast.scale(scale) + vCamera;
    Vector3 normal = intersect - vSphere;
    normal.normalize();
    return normal.z.abs();
  } else {
    return 0.0;
  }
}

void _create() {
  CanvasElement canvas = query("#canvas_ray_traced_sphere");
  CanvasRenderingContext2D ctx = canvas.context2D;
  ImageData imageData = ctx.getImageData(0, 0, canvas.width, canvas.height);
  Vector3 vSphere = new Vector3(0.0, 0.0, 5.0);
  Vector3 vCamera = new Vector3(0.0, 0.0, -6.0);
  num half_canvas_width = canvas.width / 2;
  num half_canvas_height = canvas.height / 2;
  for(num x = 0; x < canvas.width; x++) {
    for(num y = 0; y < canvas.height; y++) {
      Vector3 vScreen = new Vector3
          ((x - half_canvas_width) / 100.0, (y - half_canvas_height) / 100.0, 0.0);
      imageData.data[(y * canvas.width + x) * 4 + 0] = 0;
      imageData.data[(y * canvas.width + x) * 4 + 1] =
          (SphereRay(vCamera, vSphere, vScreen) * 200).toInt();
      imageData.data[(y * canvas.width + x) * 4 + 2] = 0;
      imageData.data[(y * canvas.width + x) * 4 + 3] = 255;
    }
  }
  ctx.putImageData(imageData, 0, 0, 0, 0, canvas.width, canvas.height);  
}

==> rad_textures-1.0.16.tar.gz: web/RayTracedSphere.dart <==
import 'dart:html';
import 'package:rad_textures/rad_textures.dart';
import 'package:vector_math/vector_math.dart';

void main() {
  window.onLoad.listen((e) => _create());
}

double /*shade*/ SphereRay(Vector3 vCamera, Vector3 vSphere, Vector3 vScreen) {
  Vector3 vCast = vScreen - vCamera;
  double scale = intersectRaySphere(vCamera, vCast, vSphere, 5.0);
  if(double.INFINITY != scale) {
    Vector3 intersect = vCast;
    intersect.scale(scale);
    intersect.add(vCamera);
    Vector3 normal = intersect - vSphere;
    normal.normalize();
    return normal.z.abs();
  } else {
    return 0.0;
  }
}

void _create() {
  CanvasElement canvas = querySelector("#canvas_ray_traced_sphere");
  CanvasRenderingContext2D ctx = canvas.context2D;
  ImageData imageData = ctx.getImageData(0, 0, canvas.width, canvas.height);
  Vector3 vSphere = new Vector3(0.0, 0.0, 5.0);
  Vector3 vCamera = new Vector3(0.0, 0.0, -6.0);
  int half_canvas_width = canvas.width ~/ 2;
  int half_canvas_height = canvas.height ~/ 2;
  for(int x = 0; x < canvas.width; x++) {
    for(int y = 0; y < canvas.height; y++) {
      Vector3 vScreen = new Vector3
          ((x - half_canvas_width) / 100.0, (y - half_canvas_height) / 100.0, 0.0);
      imageData.data[(y * canvas.width + x) * 4 + 0] = 0;
      imageData.data[(y * canvas.width + x) * 4 + 1] =
          (SphereRay(vCamera, vSphere, vScreen) * 200).toInt();
      imageData.data[(y * canvas.width + x) * 4 + 2] = 0;
      imageData.data[(y * canvas.width + x) * 4 + 3] = 255;
    }
  }
  ctx.putImageData(imageData, 0, 0, 0, 0, canvas.width, canvas.height);  
}
